summaryrefslogtreecommitdiff
path: root/src/mongo/db/transaction/transaction_participant.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/transaction/transaction_participant.cpp')
-rw-r--r--src/mongo/db/transaction/transaction_participant.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/transaction/transaction_participant.cpp b/src/mongo/db/transaction/transaction_participant.cpp
index 2d5b49665d1..e615798495f 100644
--- a/src/mongo/db/transaction/transaction_participant.cpp
+++ b/src/mongo/db/transaction/transaction_participant.cpp
@@ -451,14 +451,14 @@ void updateSessionEntry(OperationContext* opCtx,
args.criteria = toUpdateIdDoc;
args.update = updateMod;
// Specify indexesAffected = false because the sessions collection has two indexes: {_id: 1} and
// {parentLsid: 1, _id.txnNumber: 1, _id: 1}, and none of the fields are mutable.
collection_internal::updateDocument(opCtx,
*collection,
recordId,
Snapshotted<BSONObj>(startingSnapshotId, originalDoc),
updateMod,
- false, /* indexesAffected */
+ collection_internal::kUpdateNoIndexes,
nullptr,
&args);
@@ -451,14 +451,14 @@ void updateSessionEntry(OperationContext* opCtx,
args.criteria = toUpdateIdDoc;
args.update = updateMod;
- // Specify indexesAffected = false because the sessions collection has two indexes: {_id: 1} and
+ // Specify kUpdateNoIndexes because the sessions collection has two indexes: {_id: 1} and
// {parentLsid: 1, _id.txnNumber: 1, _id: 1}, and none of the fields are mutable.
collection_internal::updateDocument(opCtx,